@@ -18,6 +18,10 @@
 #include <KLocalizedString>
 #include <qstringliteral.h>
 
+#if KI18N_VERSION >= QT_VERSION_CHECK(6, 8, 0)
+#include <KLocalizedQmlContext>
+#endif
+
 #include "blankanswer.h"
 #include "exporter.h"
 #include "fileopener.h"
@@ -77,7 +81,6 @@ int main(int argc, char *argv[])
     }
 #endif
 
-    KCrash::initialize();
     KLocalizedString::setApplicationDomain(QByteArrayLiteral("kwordquiz"));
     QIcon::setFallbackThemeName(u"breeze"_s);
 
@@ -149,8 +152,11 @@ int main(int argc, char *argv[])
         return new LanguageListModel;
     });
 
+#if KI18N_VERSION < QT_VERSION_CHECK(6, 8, 0)
     engine.rootContext()->setContextObject(new KLocalizedContext(&engine));
-    QObject::connect(&engine, &QQmlApplicationEngine::quit, &app, &QCoreApplication::quit);
+#else
+    engine.rootContext()->setContextObject(new KLocalizedQmlContext(&engine));
+#endif
     engine.load(QUrl(QStringLiteral("qrc:/qml/main.qml")));
 
     const auto rootObjects = engine.rootObjects();
